@@ -38,7 +38,16 @@ class driver(object):
             self.profile["browser"]["sandbox"] = False
 
         if uc_driver:
-            import undetected_chromedriver as uc  # undetected chromedriver
+            try:
+                # noinspection PyUnresolvedReferences
+                import undetected_chromedriver as uc  # undetected chromedriver
+            except ImportError:
+                warnings.warn('undetected-chromedriver not installed. Installing..')
+                import os
+                from selenium_profiles.utils.colab_utils import patch_uc
+                os.system('pip install undetected-chromedriver')
+                patch_uc()
+            # noinspection PyUnboundLocalVariable
             self.options = uc.ChromeOptions()  # selenium.webdriver options, https://peter.sh/experiments/chromium-command-line-switches/
         else:
             self.options = webdriver.ChromeOptions()  # selenium.webdriver options, https://peter.sh/experiments/chromium-command-line-switches/
